package org.jeecg.modules.banner.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.banner.entity.WebBanner;
import org.jeecg.modules.banner.service.IWebBannerService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: banner设置
 * @Author: jeecg-boot
 * @Date:   2024-10-28
 * @Version: V1.0
 */
@Api(tags="banner设置")
@RestController
@RequestMapping("/banner/webBanner")
@Slf4j
public class WebBannerController extends JeecgController<WebBanner, IWebBannerService> {
	@Autowired
	private IWebBannerService webBannerService;
	
	/**
	 * 分页列表查询
	 *
	 * @param webBanner
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "banner设置-分页列表查询")
	@ApiOperation(value="banner设置-分页列表查询", notes="banner设置-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<WebBanner>> queryPageList(WebBanner webBanner,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<WebBanner> queryWrapper = QueryGenerator.initQueryWrapper(webBanner, req.getParameterMap());
		Page<WebBanner> page = new Page<WebBanner>(pageNo, pageSize);
		IPage<WebBanner> pageList = webBannerService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param webBanner
	 * @return
	 */
	@AutoLog(value = "banner设置-添加")
	@ApiOperation(value="banner设置-添加", notes="banner设置-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody WebBanner webBanner) {
		webBannerService.save(webBanner);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param webBanner
	 * @return
	 */
	@AutoLog(value = "banner设置-编辑")
	@ApiOperation(value="banner设置-编辑", notes="banner设置-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody WebBanner webBanner) {
		webBannerService.updateById(webBanner);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "banner设置-通过id删除")
	@ApiOperation(value="banner设置-通过id删除", notes="banner设置-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		webBannerService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "banner设置-批量删除")
	@ApiOperation(value="banner设置-批量删除", notes="banner设置-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.webBannerService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "banner设置-通过id查询")
	@ApiOperation(value="banner设置-通过id查询", notes="banner设置-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<WebBanner> queryById(@RequestParam(name="id",required=true) String id) {
		WebBanner webBanner = webBannerService.getById(id);
		if(webBanner==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(webBanner);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param webBanner
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, WebBanner webBanner) {
        return super.exportXls(request, webBanner, WebBanner.class, "banner设置");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, WebBanner.class);
    }

}
