package org.jeecg.modules.industry.controller;

import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.industry.entity.TbIndustry;
import org.jeecg.modules.industry.service.ITbIndustryService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: tb_industry
 * @Author: jeecg-boot
 * @Date:   2024-12-07
 * @Version: V1.0
 */
@Api(tags="tb_industry")
@RestController
@RequestMapping("/industry/tbIndustry")
@Slf4j
public class TbIndustryController extends JeecgController<TbIndustry, ITbIndustryService>{
	@Autowired
	private ITbIndustryService tbIndustryService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbIndustry
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "tb_industry-分页列表查询")
	@ApiOperation(value="tb_industry-分页列表查询", notes="tb_industry-分页列表查询")
	@GetMapping(value = "/rootList")
	public Result<IPage<TbIndustry>> queryPageList(TbIndustry tbIndustry,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		String hasQuery = req.getParameter("hasQuery");
        if(hasQuery != null && "true".equals(hasQuery)){
			QueryWrapper<TbIndustry> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("del_flag",0).orderByDesc("sort_no");
            List<TbIndustry> list = tbIndustryService.queryTreeListNoPage(queryWrapper);
            IPage<TbIndustry> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        }else{
            String parentId = tbIndustry.getPid();
            if (oConvertUtils.isEmpty(parentId)) {
                parentId = "0";
            }
            tbIndustry.setPid(null);
            QueryWrapper<TbIndustry> queryWrapper = QueryGenerator.initQueryWrapper(tbIndustry, req.getParameterMap());
			queryWrapper.eq("del_flag",0).orderByDesc("sort_no");
			// 使用 eq 防止模糊查询
            queryWrapper.eq("pid", parentId);
            Page<TbIndustry> page = new Page<TbIndustry>(pageNo, pageSize);
            IPage<TbIndustry> pageList = tbIndustryService.page(page, queryWrapper);
            return Result.OK(pageList);
        }
	}

	 /**
      * 获取子数据
      * @param tbIndustry
      * @param req
      * @return
      */
	//@AutoLog(value = "tb_industry-获取子数据")
	@ApiOperation(value="tb_industry-获取子数据", notes="tb_industry-获取子数据")
	@GetMapping(value = "/childList")
	public Result<IPage<TbIndustry>> queryPageList(TbIndustry tbIndustry,HttpServletRequest req) {
		QueryWrapper<TbIndustry> queryWrapper = QueryGenerator.initQueryWrapper(tbIndustry, req.getParameterMap());
		queryWrapper.eq("del_flag",0).orderByDesc("sort_no");
		List<TbIndustry> list = tbIndustryService.list(queryWrapper);
		IPage<TbIndustry> pageList = new Page<>(1, 10, list.size());
        pageList.setRecords(list);
		return Result.OK(pageList);
	}

    /**
      * 批量查询子节点
      * @param parentIds 父ID（多个采用半角逗号分割）
      * @return 返回 IPage
      * @param parentIds
      * @return
      */
	//@AutoLog(value = "tb_industry-批量获取子数据")
    @ApiOperation(value="tb_industry-批量获取子数据", notes="tb_industry-批量获取子数据")
    @GetMapping("/getChildListBatch")
    public Result getChildListBatch(@RequestParam("parentIds") String parentIds) {
        try {
            QueryWrapper<TbIndustry> queryWrapper = new QueryWrapper<>();
            List<String> parentIdList = Arrays.asList(parentIds.split(","));
            queryWrapper.in("pid", parentIdList);
            List<TbIndustry> list = tbIndustryService.list(queryWrapper);
            IPage<TbIndustry> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Result.error("批量查询子节点失败：" + e.getMessage());
        }
    }
	
	/**
	 *   添加
	 *
	 * @param tbIndustry
	 * @return
	 */
	@AutoLog(value = "tb_industry-添加")
	@ApiOperation(value="tb_industry-添加", notes="tb_industry-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbIndustry tbIndustry) {
		tbIndustryService.addTbIndustry(tbIndustry);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbIndustry
	 * @return
	 */
	@AutoLog(value = "tb_industry-编辑")
	@ApiOperation(value="tb_industry-编辑", notes="tb_industry-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbIndustry tbIndustry) {
		tbIndustryService.updateTbIndustry(tbIndustry);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "tb_industry-通过id删除")
	@ApiOperation(value="tb_industry-通过id删除", notes="tb_industry-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		TbIndustry tbIndustry = new TbIndustry();
		tbIndustry.setId(id);
		tbIndustry.setDelFlag(1);
		tbIndustryService.updateById(tbIndustry);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "tb_industry-批量删除")
	@ApiOperation(value="tb_industry-批量删除", notes="tb_industry-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbIndustryService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "tb_industry-通过id查询")
	@ApiOperation(value="tb_industry-通过id查询", notes="tb_industry-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbIndustry> queryById(@RequestParam(name="id",required=true) String id) {
		TbIndustry tbIndustry = tbIndustryService.getById(id);
		if(tbIndustry==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbIndustry);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbIndustry
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbIndustry tbIndustry) {
		return super.exportXls(request, tbIndustry, TbIndustry.class, "tb_industry");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
		return super.importExcel(request, response, TbIndustry.class);
    }

}
