package org.jeecg.modules.industry.service.impl;

import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.industry.entity.TbIndustry;
import org.jeecg.modules.industry.mapper.TbIndustryMapper;
import org.jeecg.modules.industry.service.ITbIndustryService;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.transaction.annotation.Transactional;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * @Description: tb_industry
 * @Author: jeecg-boot
 * @Date:   2024-12-07
 * @Version: V1.0
 */
@Service
public class TbIndustryServiceImpl extends ServiceImpl<TbIndustryMapper, TbIndustry> implements ITbIndustryService {

	@Override
	public void addTbIndustry(TbIndustry tbIndustry) {
	   //新增时设置hasChild为0
	    tbIndustry.setHasChild(ITbIndustryService.NOCHILD);
		if(oConvertUtils.isEmpty(tbIndustry.getPid())){
			tbIndustry.setPid(ITbIndustryService.ROOT_PID_VALUE);
		}else{
			//如果当前节点父ID不为空 则设置父节点的hasChildren 为1
			TbIndustry parent = baseMapper.selectById(tbIndustry.getPid());
			if(parent!=null && !"1".equals(parent.getHasChild())){
				parent.setHasChild("1");
				baseMapper.updateById(parent);
			}
		}
		baseMapper.insert(tbIndustry);
	}
	
	@Override
	public void updateTbIndustry(TbIndustry tbIndustry) {
		TbIndustry entity = this.getById(tbIndustry.getId());
		if(entity==null) {
			throw new JeecgBootException("未找到对应实体");
		}
		String old_pid = entity.getPid();
		String new_pid = tbIndustry.getPid();
		if(!old_pid.equals(new_pid)) {
			updateOldParentNode(old_pid);
			if(oConvertUtils.isEmpty(new_pid)){
				tbIndustry.setPid(ITbIndustryService.ROOT_PID_VALUE);
			}
			if(!ITbIndustryService.ROOT_PID_VALUE.equals(tbIndustry.getPid())) {
				baseMapper.updateTreeNodeStatus(tbIndustry.getPid(), ITbIndustryService.HASCHILD);
			}
		}
		baseMapper.updateById(tbIndustry);
	}
	
	@Override
	@Transactional(rollbackFor = Exception.class)
	public void deleteTbIndustry(String id) throws JeecgBootException {
		//查询选中节点下所有子节点一并删除
        id = this.queryTreeChildIds(id);
        if(id.indexOf(",")>0) {
            StringBuffer sb = new StringBuffer();
            String[] idArr = id.split(",");
            for (String idVal : idArr) {
                if(idVal != null){
                    TbIndustry tbIndustry = this.getById(idVal);
                    String pidVal = tbIndustry.getPid();
                    //查询此节点上一级是否还有其他子节点
                    List<TbIndustry> dataList = baseMapper.selectList(new QueryWrapper<TbIndustry>().eq("pid", pidVal).notIn("id",Arrays.asList(idArr)));
                    if((dataList == null || dataList.size()==0) && !Arrays.asList(idArr).contains(pidVal)
                            && !sb.toString().contains(pidVal)){
                        //如果当前节点原本有子节点 现在木有了，更新状态
                        sb.append(pidVal).append(",");
                    }
                }
            }
            //批量删除节点
            baseMapper.deleteBatchIds(Arrays.asList(idArr));
            //修改已无子节点的标识
            String[] pidArr = sb.toString().split(",");
            for(String pid : pidArr){
                this.updateOldParentNode(pid);
            }
        }else{
            TbIndustry tbIndustry = this.getById(id);
            if(tbIndustry==null) {
                throw new JeecgBootException("未找到对应实体");
            }
            updateOldParentNode(tbIndustry.getPid());
            baseMapper.deleteById(id);
        }
	}
	
	@Override
    public List<TbIndustry> queryTreeListNoPage(QueryWrapper<TbIndustry> queryWrapper) {
        List<TbIndustry> dataList = baseMapper.selectList(queryWrapper);
        List<TbIndustry> mapList = new ArrayList<>();
        for(TbIndustry data : dataList){
            String pidVal = data.getPid();
            //递归查询子节点的根节点
            if(pidVal != null && !"0".equals(pidVal)){
                TbIndustry rootVal = this.getTreeRoot(pidVal);
                if(rootVal != null && !mapList.contains(rootVal)){
                    mapList.add(rootVal);
                }
            }else{
                if(!mapList.contains(data)){
                    mapList.add(data);
                }
            }
        }
        return mapList;
    }
	
	/**
	 * 根据所传pid查询旧的父级节点的子节点并修改相应状态值
	 * @param pid
	 */
	private void updateOldParentNode(String pid) {
		if(!ITbIndustryService.ROOT_PID_VALUE.equals(pid)) {
			Long count = baseMapper.selectCount(new QueryWrapper<TbIndustry>().eq("pid", pid));
			if(count==null || count<=1) {
				baseMapper.updateTreeNodeStatus(pid, ITbIndustryService.NOCHILD);
			}
		}
	}

	/**
     * 递归查询节点的根节点
     * @param pidVal
     * @return
     */
    private TbIndustry getTreeRoot(String pidVal){
        TbIndustry data =  baseMapper.selectById(pidVal);
        if(data != null && !"0".equals(data.getPid())){
            return this.getTreeRoot(data.getPid());
        }else{
            return data;
        }
    }

    /**
     * 根据id查询所有子节点id
     * @param ids
     * @return
     */
    private String queryTreeChildIds(String ids) {
        //获取id数组
        String[] idArr = ids.split(",");
        StringBuffer sb = new StringBuffer();
        for (String pidVal : idArr) {
            if(pidVal != null){
                if(!sb.toString().contains(pidVal)){
                    if(sb.toString().length() > 0){
                        sb.append(",");
                    }
                    sb.append(pidVal);
                    this.getTreeChildIds(pidVal,sb);
                }
            }
        }
        return sb.toString();
    }

    /**
     * 递归查询所有子节点
     * @param pidVal
     * @param sb
     * @return
     */
    private StringBuffer getTreeChildIds(String pidVal,StringBuffer sb){
        List<TbIndustry> dataList = baseMapper.selectList(new QueryWrapper<TbIndustry>().eq("pid", pidVal));
        if(dataList != null && dataList.size()>0){
            for(TbIndustry tree : dataList) {
                if(!sb.toString().contains(tree.getId())){
                    sb.append(",").append(tree.getId());
                }
                this.getTreeChildIds(tree.getId(),sb);
            }
        }
        return sb;
    }

}
