package org.jeecg.modules.tbConf.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.tbConf.entity.TbConf;
import org.jeecg.modules.tbConf.service.ITbConfService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: tb_conf
 * @Author: jeecg-boot
 * @Date:   2024-10-28
 * @Version: V1.0
 */
@Api(tags="tb_conf")
@RestController
@RequestMapping("/tbConf/tbConf")
@Slf4j
public class TbConfController extends JeecgController<TbConf, ITbConfService> {
	@Autowired
	private ITbConfService tbConfService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbConf
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "tb_conf-分页列表查询")
	@ApiOperation(value="tb_conf-分页列表查询", notes="tb_conf-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TbConf>> queryPageList(TbConf tbConf,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TbConf> queryWrapper = QueryGenerator.initQueryWrapper(tbConf, req.getParameterMap());
		Page<TbConf> page = new Page<TbConf>(pageNo, pageSize);
		queryWrapper.eq("dict_group","sys_word");
		IPage<TbConf> pageList = tbConfService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param tbConf
	 * @return
	 */
	@AutoLog(value = "tb_conf-添加")
	@ApiOperation(value="tb_conf-添加", notes="tb_conf-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbConf tbConf) {
		tbConfService.save(tbConf);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbConf
	 * @return
	 */
	@AutoLog(value = "tb_conf-编辑")
	@ApiOperation(value="tb_conf-编辑", notes="tb_conf-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbConf tbConf) {
		tbConfService.updateById(tbConf);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "tb_conf-通过id删除")
	@ApiOperation(value="tb_conf-通过id删除", notes="tb_conf-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tbConfService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "tb_conf-批量删除")
	@ApiOperation(value="tb_conf-批量删除", notes="tb_conf-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbConfService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "tb_conf-通过id查询")
	@ApiOperation(value="tb_conf-通过id查询", notes="tb_conf-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbConf> queryById(@RequestParam(name="id",required=true) String id) {
		TbConf tbConf = tbConfService.getById(id);
		if(tbConf==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbConf);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbConf
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbConf tbConf) {
        return super.exportXls(request, tbConf, TbConf.class, "tb_conf");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TbConf.class);
    }

}
