package org.jeecg.modules.tbSuggest.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.tbSuggest.entity.TbSuggest;
import org.jeecg.modules.tbSuggest.service.ITbSuggestService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 帮助与反馈
 * @Author: jeecg-boot
 * @Date:   2024-10-19
 * @Version: V1.0
 */
@Api(tags="帮助与反馈")
@RestController
@RequestMapping("/tbSuggest/tbSuggest")
@Slf4j
public class TbSuggestController extends JeecgController<TbSuggest, ITbSuggestService> {
	@Autowired
	private ITbSuggestService tbSuggestService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbSuggest
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "帮助与反馈-分页列表查询")
	@ApiOperation(value="帮助与反馈-分页列表查询", notes="帮助与反馈-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TbSuggest>> queryPageList(TbSuggest tbSuggest,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TbSuggest> queryWrapper = QueryGenerator.initQueryWrapper(tbSuggest, req.getParameterMap());
		Page<TbSuggest> page = new Page<TbSuggest>(pageNo, pageSize);
		IPage<TbSuggest> pageList = tbSuggestService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param tbSuggest
	 * @return
	 */
	@AutoLog(value = "帮助与反馈-添加")
	@ApiOperation(value="帮助与反馈-添加", notes="帮助与反馈-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbSuggest tbSuggest) {
		tbSuggestService.save(tbSuggest);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbSuggest
	 * @return
	 */
	@AutoLog(value = "帮助与反馈-编辑")
	@ApiOperation(value="帮助与反馈-编辑", notes="帮助与反馈-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbSuggest tbSuggest) {
		tbSuggestService.updateById(tbSuggest);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "帮助与反馈-通过id删除")
	@ApiOperation(value="帮助与反馈-通过id删除", notes="帮助与反馈-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tbSuggestService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "帮助与反馈-批量删除")
	@ApiOperation(value="帮助与反馈-批量删除", notes="帮助与反馈-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbSuggestService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "帮助与反馈-通过id查询")
	@ApiOperation(value="帮助与反馈-通过id查询", notes="帮助与反馈-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbSuggest> queryById(@RequestParam(name="id",required=true) String id) {
		TbSuggest tbSuggest = tbSuggestService.getById(id);
		if(tbSuggest==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbSuggest);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbSuggest
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbSuggest tbSuggest) {
        return super.exportXls(request, tbSuggest, TbSuggest.class, "帮助与反馈");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TbSuggest.class);
    }

}
